@@ -556,11 +556,11 @@ def create_graph(
             elif node_type == 'code':
                 from ..tools.sandbox import create_sandbox_tool
                 sandbox_tool = create_sandbox_tool(stateful=False, allow_net=True)
-                code = node.get('code', "return 'Code block is empty'")
+                code_data = node.get('code', {'type': 'fixed', 'value': "return 'Code block is empty'"})
                 lg_builder.add_node(node_id, FunctionTool(
                     tool=sandbox_tool, name=node['id'], return_type='dict',
                     output_variables=node.get('output', []),
-                    input_mapping={'code': {'type': 'fixed', 'value': code}},
+                    input_mapping={'code': code_data},
                     input_variables=node.get('input', ['messages']),
                     structured_output=node.get('structured_output', False),
                     alita_client=kwargs.get('alita_client', None)
@@ -780,7 +780,10 @@ class LangGraphAgentRunnable(CompiledStateGraph):
         
         # Append current input to existing messages instead of overwriting
         if input.get('input'):
-            current_message = input.get('input')[-1]
+            if isinstance(input['input'], str):
+                current_message = input['input']
+            else:
+                current_message = input.get('input')[-1]
             # TODO: add handler after we add 2+ inputs (filterByType, etc.)
             input['input'] = current_message if isinstance(current_message, str) else str(current_message)
             if input.get('messages'):
